"""
This module provides functions to convert a pdf to text
"""


def convert(path):
    """
    convert the given pdf to text

    paremeters:
    path(str):The path to a pdf file.
    returns:
    str:The content of the pdf file as text
    """
    print("pdf2text")
